# Generated by roxygen2: do not edit by hand

S3method(print,gwpr_bandwidth)
S3method(print,gwpr_diagnostics)
S3method(print,gwpr_fit)
S3method(summary,gwpr_bandwidth)
S3method(summary,gwpr_diagnostics)
S3method(summary,gwpr_fit)
export(diagnose_gwpr)
export(diagnose_hausman)
export(diagnose_lm)
export(diagnose_local_f)
export(diagnose_moran)
export(fit_gwpr)
export(gwpr)
export(parallel_map)
export(select_bandwidth)
export(with_reproducible_seed)
importFrom(stats,binomial)
importFrom(stats,quantile)
