% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bandwidth_sgd.R
\name{bandwidth_sgd}
\alias{bandwidth_sgd}
\title{SGD Bandwidth Search (`bandwidth_sgd.R`)}
\description{
Implements a stochastic gradient descent (SGD) based bandwidth search for
GWPR models.  A one-dimensional finite-difference gradient approximation is
used to iteratively update the bandwidth over a fixed number of epochs.
Mini-batch sampling and early stopping are supported.

The search does **not** require the user to specify `lower`, `upper`, or
`step`; SGD starts from a single initialised bandwidth and follows the
(approximate) gradient.  When `lower` / `upper` are supplied they are used
as hard constraints.
}
\keyword{internal}
