% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/result.R
\name{summary.gwpr_fit}
\alias{summary.gwpr_fit}
\title{Summarise a gwpr_fit object}
\usage{
\method{summary}{gwpr_fit}(object, ...)
}
\arguments{
\item{object}{A `gwpr_fit` object.}

\item{...}{Currently ignored.}
}
\value{
Invisibly returns `object`.
}
\description{
Prints the global model overview, quantile summary of local coefficients
(when available), and goodness-of-fit metrics.
}
\examples{
\donttest{
library(sf)
pts <- sf::st_as_sf(
  data.frame(id = 1:4, X = c(0,1,0,1), Y = c(0,0,1,1)),
  coords = c("X", "Y"), crs = NA_integer_
)
dat <- data.frame(id = rep(1:4, each = 5), time = rep(1:5, 4),
                  y = rnorm(20), x1 = rnorm(20))
fit <- fit_gwpr(y ~ x1, data = dat, spatial = pts, id = "id",
                time = "time", bandwidth = 2, workers = 1)
summary(fit)
}

}
