% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/result.R
\name{summary.gwpr_bandwidth}
\alias{summary.gwpr_bandwidth}
\title{Summarise a gwpr_bandwidth object}
\usage{
\method{summary}{gwpr_bandwidth}(object, ...)
}
\arguments{
\item{object}{A `gwpr_bandwidth` object.}

\item{...}{Currently ignored.}
}
\value{
Invisibly returns `object`.
}
\description{
Prints the search method, best bandwidth, and a brief history overview.
}
\examples{
\donttest{
library(sf)
pts <- sf::st_as_sf(
  data.frame(id = 1:4, X = c(0,1,0,1), Y = c(0,0,1,1)),
  coords = c("X", "Y"), crs = NA_integer_
)
dat <- data.frame(id = rep(1:4, each = 5), time = rep(1:5, 4),
                  y = rnorm(20), x1 = rnorm(20))
bw <- select_bandwidth(y ~ x1, data = dat, spatial = pts, id = "id",
  time = "time", method = "grid",
  control = list(lower = 1, upper = 3, step = 1), workers = 1)
summary(bw)
}

}
