% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bandwidth_grid.R
\name{bandwidth_grid}
\alias{bandwidth_grid}
\title{Grid Search for Bandwidth Selection}
\description{
Functions implementing an exhaustive grid search over a user-specified
range of bandwidth candidates.  Each candidate is evaluated by a user-
supplied scorer function; the full search history and the best bandwidth
are returned as a `gwpr_bandwidth` object.
}
\keyword{internal}
