% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/spatial_sf.R
\name{assert_sf}
\alias{assert_sf}
\title{Assert that an object is an sf object}
\usage{
assert_sf(spatial)
}
\arguments{
\item{spatial}{Any R object.}
}
\value{
Invisibly returns `TRUE` when the check passes.
}
\description{
Stops with an informative error when `spatial` does not inherit from `"sf"`.
sp objects are not supported.
}
\keyword{internal}
