% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/result.R
\name{result}
\alias{result}
\title{Result Object Module for GWPR.light 1.0.0}
\description{
S3 classes and constructor functions for the three result objects returned
by the GWPR.light public API: `gwpr_fit`, `gwpr_bandwidth`, and
`gwpr_diagnostics`.  Also provides `build_spatial_results()` for assembling
a data.frame that can be aligned with an `sf` geometry column.
}
