% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validation.R
\name{validate_spatial}
\alias{validate_spatial}
\title{Validate a spatial sf object}
\usage{
validate_spatial(spatial, id)
}
\arguments{
\item{spatial}{An `sf` object representing spatial units.}

\item{id}{Name of the ID column that must be present in `spatial`.}
}
\value{
Invisibly returns `TRUE` when valid; stops otherwise.
}
\description{
Validate a spatial sf object
}
\keyword{internal}
