% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bandwidth_sgd.R
\name{.make_na_history_row}
\alias{.make_na_history_row}
\title{Create a placeholder NA history row for epochs after early stopping}
\usage{
.make_na_history_row(ep, bw, learning_rate, delta, batch_size)
}
\description{
Create a placeholder NA history row for epochs after early stopping
}
\keyword{internal}
