% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_prepare.R
\name{extract_coords_from_sf}
\alias{extract_coords_from_sf}
\title{Extract representative XY coordinates from an sf object}
\usage{
extract_coords_from_sf(spatial)
}
\arguments{
\item{spatial}{An `sf` object.}
}
\value{
A numeric matrix with columns `X` and `Y`.
}
\description{
Uses point coordinates for POINT geometries and centroids for other
geometry types (POLYGON, MULTIPOLYGON, etc.).
}
\keyword{internal}
