% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/model_logistic.R
\name{predict_logistic_local_model}
\alias{predict_logistic_local_model}
\title{Predict probabilities for a local logistic model}
\usage{
predict_logistic_local_model(local_result, local_data)
}
\arguments{
\item{local_result}{A list as returned by \code{fit_logistic_local_model()}.}

\item{local_data}{A \code{data.frame} used for prediction.}
}
\value{
Numeric vector of probabilities in \code{[0, 1]}.  Returns a vector
  of \code{NA_real_} on failure.
}
\description{
Returns predicted probabilities (type = \code{"response"}) for the rows of
\code{local_data}, using the fitted model stored in \code{local_result}.
}
\keyword{internal}
