% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validation.R
\name{validate_workers}
\alias{validate_workers}
\title{Validate the workers argument}
\usage{
validate_workers(workers)
}
\arguments{
\item{workers}{Number of parallel workers. Must be a positive integer.}
}
\value{
Invisibly returns `TRUE` when valid; stops otherwise.
}
\description{
Validate the workers argument
}
\keyword{internal}
