% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metrics.R
\name{metrics}
\alias{metrics}
\title{Metrics Module}
\description{
Functions for computing evaluation metrics for linear and
  logistic panel regression models.
}
