% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validation.R
\name{validate_panel_index}
\alias{validate_panel_index}
\title{Validate panel index columns in a data frame}
\usage{
validate_panel_index(data, id, time)
}
\arguments{
\item{data}{A data frame.}

\item{id}{Name of the unit (individual) index column.}

\item{time}{Name of the time index column.}
}
\value{
Invisibly returns `TRUE` when valid; stops otherwise.
}
\description{
Validate panel index columns in a data frame
}
\keyword{internal}
