% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_prepare.R
\name{build_model_frame}
\alias{build_model_frame}
\title{Build the model frame from the formula and panel data}
\usage{
build_model_frame(context)
}
\arguments{
\item{context}{A `gwpr_context` with `formula` and `panel_data` populated.}
}
\value{
Updated context with `model_frame` populated.
}
\description{
Build the model frame from the formula and panel data
}
\keyword{internal}
